summaryrefslogtreecommitdiffstats
path: root/ksvg/impl/SVGEventImpl.cc
diff options
context:
space:
mode:
Diffstat (limited to 'ksvg/impl/SVGEventImpl.cc')
-rw-r--r--ksvg/impl/SVGEventImpl.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/ksvg/impl/SVGEventImpl.cc b/ksvg/impl/SVGEventImpl.cc
index 38ab5e64..e1252af8 100644
--- a/ksvg/impl/SVGEventImpl.cc
+++ b/ksvg/impl/SVGEventImpl.cc
@@ -507,17 +507,17 @@ SVGKeyEventImpl::SVGKeyEventImpl(TQKeyEvent *key, DOM::AbstractView &view, SVGEv
break;
}
// m_keyVal should contain the tqunicode value
// of the pressed key if available.
if (!key->text().isNull())
- m_keyVal = TQString(key->text()).tqunicode()[0];
+ m_keyVal = TQString(key->text()).unicode()[0];
// m_numPad = ???
// key->state returns enum ButtonState, which is ShiftButton, ControlButton and AltButton or'ed together.
m_modifier = key->state();
// key->text() returns the tqunicode sequence as a TQString
m_outputString = DOM::DOMString(key->text());
}
@@ -507,17 +507,17 @@ SVGKeyEventImpl::SVGKeyEventImpl(TQKeyEvent *key, DOM::AbstractView &view, SVGEv
break;
}
- // m_keyVal should contain the tqunicode value
+ // m_keyVal should contain the unicode value
// of the pressed key if available.
if (!key->text().isNull())
@@ -507,17 +507,17 @@ SVGKeyEventImpl::SVGKeyEventImpl(TQKeyEvent *key, DOM::AbstractView &view, SVGEv
// key->state returns enum ButtonState, which is ShiftButton, ControlButton and AltButton or'ed together.
m_modifier = key->state();
- // key->text() returns the tqunicode sequence as a TQString
+ // key->text() returns the unicode sequence as a TQString
m_outputString = DOM::DOMString(key->text());
}